Documentation
¶
Index ¶
- type Assertion
- func (a *Assertion) NotToBe(nonExpectedValue any)
- func (a *Assertion) NotToBeNil()
- func (a *Assertion) ToBe(expectedValue any)
- func (a *Assertion) ToBeNil()
- func (a *Assertion) ToContainJSON(expectedJSON string)
- func (a *Assertion) ToMatchJSON(expectedJSON string)
- func (a *Assertion) ToMatchPattern(pattern string)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Assertion ¶
func (*Assertion) NotToBeNil ¶
func (a *Assertion) NotToBeNil()
func (*Assertion) ToContainJSON ¶
func (*Assertion) ToMatchJSON ¶
func (*Assertion) ToMatchPattern ¶
TODO: Make the string parsing more robust and universal Example: When calling err.Error() but the error is nil, the test suite immediately throws a nil pointer dereference error (ugly). Instead what I would love to have is a situation where the matcher tries to parse the error to string and notices that the error is nil (Expected xxx to be a string, but is nil instead)
Click to show internal directories.
Click to hide internal directories.